"use strict";
exports.__esModule = true;
exports.FileLogger = void 0;
var utils_1 = require("./utils");
var fs_1 = require("fs");
var levels_1 = require("./levels");
var date_utils_1 = require("./commons/date-utils");
var FileLogger = /** @class */ (function () {
    function FileLogger() {
        this.format = "{date} - [ {level} ] - {msg}";
        this.dateFormat = "{weekDay} {day}/{month}/{year} : {hour}:{min}:{sec}";
    }
    FileLogger.getLogger = function () {
        if (!FileLogger._instance)
            FileLogger._instance = new FileLogger();
        return FileLogger._instance;
    };
    FileLogger.prototype.fmtText = function (text) {
        var data = utils_1.Formatter.formatText(text, FileLogger._length);
        if (data.maxLength > FileLogger._length) {
            FileLogger._length = data.maxLength;
        }
        return data.text;
    };
    FileLogger.prototype.buildEssentials = function (obj) {
        var out = obj;
        var dateObj = (0, date_utils_1.makeDateObject)();
        out.date = utils_1.Formatter.formatObj(this.dateFormat, dateObj);
        return out;
    };
    FileLogger.prototype.check = function (lvl) {
        return levels_1.LogLevel.checkLevel(levels_1.LogLevel.getLevel4(lvl), this.loglevel);
    };
    FileLogger.prototype.writeLog = function (line) {
        if (!this.logFile) {
            console.error("LogFile not set");
            return;
        }
        (0, fs_1.appendFileSync)(this.logFile, line + "\n");
    };
    FileLogger.prototype.writeError = function (line) {
        if (!this.errorFile) {
            this.writeLog(line);
        }
        else {
            (0, fs_1.appendFileSync)(this.errorFile, line + "\n");
        }
    };
    FileLogger.prototype.info = function (msg, data) {
        if (data === void 0) { data = {}; }
        if (!this.check("info"))
            return;
        var _data = data;
        _data.msg = utils_1.Formatter.formatObj(msg, data);
        _data = this.buildEssentials(_data);
        _data.level = this.fmtText("INFO");
        var line = utils_1.Formatter.formatObj(this.format, _data);
        this.writeLog(line);
    };
    FileLogger.prototype.warn = function (msg, data) {
        if (data === void 0) { data = {}; }
        if (!this.check("warn"))
            return;
        var _data = data;
        _data.msg = utils_1.Formatter.formatObj(msg, data);
        _data = this.buildEssentials(_data);
        _data.level = this.fmtText("WARN");
        var line = utils_1.Formatter.formatObj(this.format, _data);
        this.writeLog(line);
    };
    FileLogger.prototype.log = function (msg, data) {
        if (data === void 0) { data = {}; }
        if (!this.check("log"))
            return;
        var _data = data;
        _data.msg = utils_1.Formatter.formatObj(msg, data);
        _data = this.buildEssentials(_data);
        _data.level = this.fmtText("LOG");
        var line = utils_1.Formatter.formatObj(this.format, _data);
        this.writeLog(line);
    };
    FileLogger.prototype.error = function (msg, data) {
        if (data === void 0) { data = {}; }
        if (!this.check("error"))
            return;
        var _data = data;
        _data.msg = utils_1.Formatter.formatObj(msg, data);
        _data = this.buildEssentials(_data);
        _data.level = this.fmtText("ERROR");
        var line = utils_1.Formatter.formatObj(this.format, _data);
        this.writeError(line);
    };
    FileLogger.prototype.critical = function (msg, data) {
        if (data === void 0) { data = {}; }
        if (!this.check("critical"))
            return;
        var _data = data;
        _data.msg = utils_1.Formatter.formatObj(msg, data);
        _data = this.buildEssentials(_data);
        _data.level = this.fmtText("CRITICAL");
        var line = utils_1.Formatter.formatObj(this.format, _data);
        "";
        this.writeError(line);
    };
    FileLogger.prototype.debug = function (msg, data) {
        if (data === void 0) { data = {}; }
        if (!this.check("debug"))
            return;
        var _data = data;
        _data.msg = utils_1.Formatter.formatObj(msg, data);
        _data = this.buildEssentials(_data);
        _data.level = this.fmtText("DEBUG");
        var line = utils_1.Formatter.formatObj(this.format, _data);
        this.writeLog(line);
    };
    FileLogger.prototype.setFormat = function (format) {
        this.format = format;
        return this;
    };
    FileLogger.prototype.setDateFormat = function (format) {
        this.dateFormat = format;
        return this;
    };
    FileLogger.prototype.setLogFile = function (file) {
        this.logFile = file;
        return this;
    };
    FileLogger.prototype.setErrorFile = function (file) {
        this.errorFile = file;
        return this;
    };
    FileLogger.prototype.setLogLevel = function (lvl) {
        this.loglevel = levels_1.LogLevel.getLevel4(lvl);
        return this;
    };
    FileLogger._length = 10;
    return FileLogger;
}());
exports.FileLogger = FileLogger;
